import os
import logging
import json
from flask import Flask, render_template, abort, jsonify, session, url_for, request, redirect
from pprint import pformat

from p2.store.client import Client
from p2.logging import HttpLogger

from p2.ui.config import settings
from p2.ui.config.lib import ConfigLib

app = Flask(__name__)
app.config.from_object('p2.ui.config.settings')
app.secret_key = app.config['SECRET_KEY']

log = HttpLogger(
    level = logging.DEBUG,
    silent = False,
    name='p2.ui.config'
)
logger = log.getLogger()

p2_store_url = os.getenv('P2_STORE_URL')
if p2_store_url is None:
    raise Exception("No P2_STORE_URL envar found")

client = Client(p2_store_url)
lib = ConfigLib()

@app.route('/api/display_components_list')
def display_components_list():
    recs = client.select(
        table='config',
        fetch=['component', 'tag'],
        sort='component, tag'
    )
    return jsonify(recs)

@app.route('/api/get_component_config/<component>/<tag>')
def get_component_config(component: str, tag: str):

    logger.debug(f"Getting config for component: {component}")
    rec = client.select(
        table='config',
        fetch=['config'],
        filter={
            'component': component,
            'tag': tag
        })

    if rec is None or len(rec) != 1:
        abort(404)
    else:
        text = rec[0]['config']
        return text

@app.route('/api/update_config/<component>', methods=['POST'])
def update_config(component: str):
    try:
        app.logger.debug(f"Component: {component}")
        data = request.get_json(force=True)
        app.logger.debug(f"Data: {data}")

        new_record = lib.update_config(data)
        return jsonify(new_record)
    except Exception as e:
        app.logger.error(f"Error updating config: {e}")
        abort(500)


if __name__ == '__main__':
      app.run(host='0.0.0.0', port=6000)
