import unittest
import requests
import sys
import os
import json
import logging
from pprint import pprint

from p2.store.client import Client
from p2.ui.config.lib import ConfigLib

import http.client as http_client
http_client.HTTPConnection.debuglevel = 1

# You must initialize logging, otherwise you'll not see debug output.
logging.basicConfig(filename='server.log', level=logging.INFO)
requests_log = logging.getLogger("requests.packages.urllib3")
requests_log.setLevel(logging.INFO)
requests_log.propagate = True

base_url = 'http://localhost:6000'
headers = {'Content-Type': 'application/json' }

class TestResources(unittest.TestCase):

    def test_get_components_list(self):
        url = base_url + '/api/display_components_list'
        resp = requests.get(url, headers=headers, timeout=5)
        self.assertEqual( resp.status_code, 200)
        self.assertEqual( resp.json(), [
            {'component': 'p2.agent', 'tag': None},
            {'component': 'p2.reporter.access', 'tag': None},
            {'component': 'p2.scheduler', 'tag': 'minikube'}
        ])

    def test_configlib_update_config(self):
        try:
            cl = ConfigLib()
            client = Client(os.getenv('P2_STORE_URL'))
            configs = client.select( table='config', sort='component' )
            if configs == None or len(configs) == 0:
                raise Exception("Error getting a configuration to update...")
            new_config = cl.update_config(configs[0])
            self.assertDictEqual(configs[0], new_config)
        except Exception as e:
            raise Exception(e)

    def test_update_config(self):
        client = Client(os.getenv('P2_STORE_URL'))
        configs = client.select( table='config', sort='component' )
        if configs == None or len(configs) == 0:
            raise Exception("Error getting a configuration to update...")

        url = base_url + '/api/update_config/' + configs[0]['component']
        resp = requests.post(
            url=url,
            json=configs[0],
            headers=headers,
            timeout= 5
        )
        self.assertDictEqual(configs[0], resp.json())
